@@ -60,8 +60,8 @@ See F<LICENSE>.
 
 =cut
 
-$^V eq 5.32.1 
-    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
+$^V eq 5.34.0 
+    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                    "that PAR::Packer was built with; please rebuild PAR::Packer", 
                    $^X, $^V);
 
@@ -76,7 +76,7 @@ M`0```.B.``#HC@$`Z(X!`)0"``"H$@``!@```````0`"````\(X``/".`0#P
 MC@$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
 M```$````4>5T9```````````````````````````!@```!````!2Y71DZ(X`
 M`.B.`0#HC@$`&`$``!@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
-M!````!0````#````1TY5`)_+\:6%0UIN0@IFGMXVU`(Z_>JN!````!`````!
+M!````!0````#````1TY5`+9`C_-OP0[307+&J$#&#M9"49=1!````!`````!
 M````1TY5```````#`````@`````````]````3`````@````(`````9`0!"5`
 M!(`H@``%H(90A(`!```+*`2,.*`218H```@``````````$P`````````30``
 M`$X```!0`````````%$`````````4@```%,```!4````50````````!6````
@@ -152,7 +152,7 @@ M7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`
 M7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A
 M<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
 M7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)
-M0D-?,BXT`"]U<W(O;&EB+W!E<FPU+S4N,S(O8V]R95]P97)L+T-/4D4`````
+M0D-?,BXT`"]U<W(O;&EB+W!E<FPU+S4N,S0O8V]R95]P97)L+T-/4D4`````
 M`````@`"``(``@`"`````P`"``(``@`$``(````"```````"``(``@`"``(`
 M`@````````````(``@````,````"``,``@`"```````"``(``@````(````#
 M``(```````(``@````````````(````"``(````"`````@`"``````````(`
@@ -204,7 +204,7 @@ M!F"/X`P`EN4%(*#A`1"/X'3__^L`0%#B)P``"BA1G^488(WB!5"/X`P`E>4?
 M___K&`&?Y080H.$``(_@IP``ZP``4.,@```*!#&?Y0,PC^`,`)/E`/__ZUS_
 M_^OT()_EM#"?Y0(@C^`#,)+G`""3Y1PPG>4"(#/@(P``&@0`H.$@T(WB<("]
 MZ!'__^O(()_E`B"/X```4.,,`(+E&P``"NK^_^N$,)_E`T"4YP``E.5\___K
-M25?`Y9S__^H,`);E8___ZP!`H.'3___J"`"5Y0``4.,!```*4`@`Z]G__^IX
+M1U?`Y9S__^H,`);E8___ZP!`H.'3___J"`"5Y0``4.,!```*4`@`Z]G__^IX
 M`)_E!A"@X0``C^![``#K``!0XP@`A>72__\*]?__ZD?__^L0X*#CM___ZMO^
 M_^L!`*#C#/__ZP1Z`0`,`0``R'D!`"@!```P`0``&`$``!0!``"X>@$`N'H!
 M`*@U``"8-0``1'H!`$`*```@>@$`Z#(``/AY`0!@>`$`M'D!`-@Q````L*#C
